###############################################################################
# Orkid Build System
# Copyright 2010-2020, Michael T. Mayers
# email: michael@tweakoz.com
# The Orkid Build System is published under the GPL 2.0 license
# see http://www.gnu.org/licenses/gpl-2.0.html
###############################################################################
from obt import dep, path, host
###############################################################################
class eigen(dep.StdProvider):
  name = "eigen"
  def __init__(self):
    super().__init__(eigen.name)
    self.declareDep("cmake")
    self._builder = self.createBuilder(dep.CMakeBuilder)

    #self._builder.requires(["lapack"])

  ########################################################################
  @property
  def _fetcher(self):
    fetcher = dep.GitFetcher(eigen.name)
    fetcher._git_url = "git@github.com:tweakoz/eigen.git"
    fetcher._cache=False,
    fetcher._recursive=False
    fetcher._revision = "3.4.0"
    return fetcher
  #######################################################################
  def areRequiredSourceFilesPresent(self):
    return (self.source_root/"CMakeLists.txt").exists()

  def areRequiredBinaryFilesPresent(self):
    return (path.stage()/"share"/"pkgconfig"/"eigen3.pc").exists()

  def compileenv(self): ##########################################################
    return {
        "INCLUDE_PATH": path.includes()/"eigen3"
    }



#!/usr/bin/env python3

import os, sys, subprocess, argparse

from obt import command, path, pathtools
from obt import sdk, dep, subspace, conan

IOS_SUBSPACE_DIR = subspace.descriptor("ios")._subsrc
IOS_SDK = sdk.descriptor("aarch64","ios")
prefix = path.subspace_dir()

my_build_dir = prefix/"builds"/"conanapp"
pathtools.ensureDirectoryExists(my_build_dir)

assert(subspace.current() == "ios")

##############################################

os.chdir(my_build_dir)

lexertl = dep.require("lexertl14")
parsertl = dep.require("parsertl14")

conan.require(prefix,my_build_dir,[
  "zlib/1.2.11",
  "boost/1.81.0",
  "lexertl14/tweakoz-obt@user/channel",
])

##############################################

IOS_SDK = sdk.descriptor("aarch64","ios")
the_environ = conan.environment()
the_environ.update(IOS_SDK._environment)
the_environ.update({
  "OBT_SUBSPACE_BUILD_DIR": prefix/"builds",
  "OBT_SUBSPACE_LIB_DIR": prefix/"lib",
  "OBT_SUBSPACE_BIN_DIR": prefix/"bin",
})

##############################################

command.run(["cp", IOS_SUBSPACE_DIR/"CMakeListsConan.txt", my_build_dir/"CMakeLists.txt"], do_log=True)
command.run(["cp", IOS_SUBSPACE_DIR/"InfoConan.plist", my_build_dir/"Info.plist"], do_log=True)
  
##############################################


the_environ["VERBOSE"] = "1"

print( "############## begin envdump ##############")

for item in the_environ:
  print(f"{item}={the_environ[item]}")

print( "############## end envdump ##############")

##############################################

pathtools.mkdir(my_build_dir/".build-conan",clean=True)
os.chdir(my_build_dir/".build-conan")
command.run(["cmake", "..", "-G", "Xcode"], environment=the_environ, do_log=True)
command.run(["cmake", "--build", ".","--config", "Release"], environment=the_environ, do_log=True)

##############################################

app_bundle_dir = my_build_dir / ".build-conan/Release-iphoneos/ios_conan_app.app"
# Verify the executable exists within the bundle
executable_path = app_bundle_dir / "ios_conan_app"
if not os.path.exists(executable_path):
    print(f"Executable not found at {executable_path}")
    sys.exit(1)

##############################################
# Install the app on the connected device
##############################################

IOS_SDK.install_app("com.example.conanapp", app_bundle_dir)



#!/usr/bin/env python3

from ork import path, pathtools, command
import os
from pathlib import Path

this_path = os.path.realpath(__file__)
this_dir = Path(os.path.dirname(this_path))

builddir = path.builds()/"amigadev-test1"
pathtools.mkdir(builddir,clean=True)

command.run([
    "docker", "run",
    "-it",
    "--mount","type=bind,source=%s,target=/home/amigadev/test1,readonly"%this_dir,
    "--mount","type=bind,source=%s,target=/home/amigadev/test1-build"%builddir,
    "obt-amigadev:latest",
    "./test1/_build.sh"])



#!/usr/bin/env python3

from obt import subspace, host, path, pathtools
from obt.path import Path 

import os 

this_path = os.path.realpath(__file__)
this_dir = Path(os.path.dirname(this_path))

#####################################
# install conda pytorch modules
#####################################

conda = subspace.requires("conda")

cmdlist = [
  "install",
  "pytorch", "torchvision",
  "tensorboard"
]

if host.IsLinux:
  cmdlist += ["cudatoolkit=11.3"]
elif host.IsOsx and host.IsX86_64:
  cmdlist += ["torchaudio"]

cmdlist += [ "-c", "pytorch", "-y" ]

conda.command(cmdlist)

#####################################
# cd to temp so that traingin data 
#   download does not pollute git repo
#####################################

pathtools.chdir(path.temp()) 

#####################################
# launch a training test..
#####################################

conda.launch([this_dir/"training.py"])



from obt import command, path, pathtools, sdk, dep, subspace

prefix = path.subspace_dir()

the_environ = {
  "CONAN_HOME": prefix/"conan",
  "CONAN_USER_HOME": prefix/"conan",
  "CONAN_CACHE_DIR": "~/.obt-global/conan2"
}

##############################################

def environment():
  return the_environ

##############################################
# generate conanfile
##############################################

# missing 
# glfw
# lexertl14
# parsertl14
# easyprof 
# rtmidi 
# cpppeglib 
# klein 
# portaudio 

# not working
#libigl/2.3.0
#openimageio/2.5.6
#rapidjson/cci.20230929 <incompatible with assimp/5.2.2>
#openblas/0.3.26 
#"libsndfile/1.2.2",

#lexertl = dep.instance("lexertl14")
#print(lexertl)
#print(dir(lexertl))

conanfile = """
[requires]
zlib/1.2.11
boost/1.81.0
assimp/5.2.2
ptex/2.4.2
openexr/3.2.1
rapidjson/cci.20220822
eigen/3.4.0
glm/cci.20230113
bullet3/3.25
zeromq/4.3.5
cppzmq/4.10.0
sigslot/1.2.2 
moltenvk/1.2.2
lexertl14/tweakoz-obt
"zeromq/4.3.4",
"zmqpp/4.2.0",
"tracy/cci.20220130",
"stb/cci.20230920"
  "sqlite3/3.45.0",
  "sqlitecpp/3.3.1",
  "libbacktrace/cci.20210118",
  "audiofile/1.1.1",
  "alembic/1.8.6",
[generators]
CMakeDeps
CMakeToolchain
"""
  
def require(prefix,build_dir,deplist):

  conanfile = "[requires]\n"

  for item in deplist:
    conanfile += f"{item}\n"

  conanfile += "\n"
  conanfile += "[generators]\n"
  conanfile += "CMakeDeps\n"
  conanfile += "CMakeToolchain\n"

  cf_output = build_dir/"conanfile.txt"
  with open(cf_output,"w") as f:
    f.write(conanfile)

  ##############################################
    
  cmd =  ["conan","install","."]
  cmd += [f"--profile:host={prefix}/ios.host.profile"]
  cmd += [f"--profile:build={prefix}/ios.build.profile"]
  cmd += ["--build=missing"]

  command.run(cmd, #
              environment=the_environ, #
              working_dir=build_dir, #
              do_log=True)
